import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { ReceiptService } from '../receipt.service';
import { Order} from '../order/order.model';
import { Observable }  from 'rxjs';
import { faCheck, faHourglass } from '@fortawesome/free-solid-svg-icons';

var QRCode = require('easyqrcodejs');
var URLSafeBase64 = require('urlsafe-base64');
var Buffer = require('buffer/').Buffer;

@Component({
  selector: 'app-invoice',
  templateUrl: './invoice.component.html',
  styleUrls: ['./invoice.component.css']
})
export class InvoiceComponent implements OnInit {
	faCheck = faCheck;
	faHourglass = faHourglass;
	orderId;
	public orderUpdate: Observable<Order>;
	public nameUpdate: Observable<string>;
	name: string = '';
	error: boolean = false;
	codeString: string = 'Test';

	order:Order = {
			address: '',
			session: '',
			timestamp: '',
			closed: false,
			currency: '',
			price: 0,
			total: 0,
			totalZec: 0,
			paid: false,
			lines: [
				{
					qty: 1,
					name: '',
					cost:0
				}
			]
		};

	constructor(
		private _ActiveRoute:ActivatedRoute,
		private router: Router,
		public receiptService: ReceiptService
	) {
		this.orderId = this._ActiveRoute.snapshot.paramMap.get("orderId");
		this.orderUpdate = receiptService.orderUpdate;
		this.nameUpdate = receiptService.nameUpdate;
		receiptService.getOrderById(this.orderId!).subscribe(response => {
			if (response.status == 200){
				this.error = false;
				this.codeString = `zcash:${response.body!.order.address}?amount=${response.body!.order.totalZec.toFixed(8)}&memo=${URLSafeBase64.encode(Buffer.from('ZGo Order::'.concat(this.orderId!)))}`; 
				var qrcode = new QRCode(document.getElementById("payment-qr"), {
		        text: this.codeString,
						logo: "/assets/zcash.png",
						width: 180,
						height: 180,
						logoWidth: 50,
						logoHeight: 50,
		        correctLevel: QRCode.CorrectLevel.H
				});
			} else {
				this.error = true;
				this.codeString = 'Test';
			}
		});
		this.orderUpdate.subscribe(order => {
			this.order = order;
		});
		this.nameUpdate.subscribe(name => {
			this.name = name;
		});
	}

	ngOnInit(): void {
	}

	getIconStyle(order : Order) {
		if( order.paid )
		  return "font-size: 14px; color: #72cc50; margin-bottom: -2px;";
		return "color: #FB4F14; margin-bottom: -2px; cursor: pointer;";

	}

}
